%define	major		3
%define libname		%mklibname %name %major
%define develname	%mklibname %name -d

#define advanced_branch	1

# Upstream libxml2 backend is completely broken since 2015
# https://sourceforge.net/p/xmlrpc-c/patches/49/
%bcond_with libxml2

Name:		xmlrpc-c
Summary:	Programming library for writing an XML-RPC server or client in C or C++
Version:	1.51.06
%define subrel 1
Release:	%mkrel 1
Group:		System/Libraries
# See doc/COPYING for details.
# The Python 1.5.2 license used by a few files is just BSD.
License:        BSD and MIT
URL:            http://xmlrpc-c.sourceforge.net/
%{!?advanced_branch:Source0: https://downloads.sourceforge.net/xmlrpc-c/xmlrpc-c-%version.tgz}
# generated by 'make svn-sources [SVN_VER=version SVN_REV=rev]'. Unfortunately,
# upstream does not tag versions so we must fetch from the branch and
# check which version was used for it
%{?advanced_branch:Source0: xmlrpc-c-%version.tar.xz}

# Upstreamable patches
Patch101:       0001-xmlrpc_server_abyss-use-va_args-properly.patch
Patch102:       0002-Use-proper-datatypes-for-long-long.patch
Patch103:       0003-allow-30x-redirections.patch
#Patch104:       xmlrpc-c-printf-size_t.patch
#Patch105:       xmlrpc-c-check-vasprintf-return-value.patch

# Meson buildsystem, see https://blogs.gnome.org/ignatenko/2016/12/17/meson-%E2%99%A5-xmlrpc-c/
Patch1001:      0001-add-meson-buildsystem-definitions.patch
Patch1002:      0002-chmod-x-xml-rpc-api2txt.patch

Patch2004:      0004-Add-missing-validation-of-encoding-CVE-2022-25235.patch

BuildRequires:  git-core
BuildRequires:  meson >= 0.36.0
BuildRequires:  gcc
BuildRequires:  gcc-c++
%if %{with libxml2}
BuildRequires:  pkgconfig(libxml-2.0)
%endif
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(readline)
BuildRequires:  ncurses-devel

%description
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C and C++.

%files
%doc doc/COPYING doc/CREDITS doc/DEVELOPING
%doc doc/HISTORY doc/SECURITY doc/TESTING doc/TODO
%{_bindir}/xmlrpc
%{_bindir}/xmlrpc_dumpserver
%{_bindir}/xmlrpc_parsecall
%{_bindir}/xmlrpc_pstream
%{_bindir}/xmlrpc_transport
%{_bindir}/xml-rpc-api2cpp
%{_bindir}/xml-rpc-api2txt
%{_bindir}/xmlrpc_cpp_proxy
%{_mandir}/man1/xml-rpc-api2cpp.1*
%{_mandir}/man1/xml-rpc-api2txt.1*

#--------------------------------------------------------------------

%package -n %{libname}
Summary:	Programming library for writing an XML-RPC server or client in C or C++
Group:		System/Libraries

%description -n %{libname}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C and C++.

%files -n %{libname}
%{_libdir}/lib*.so.*

#--------------------------------------------------------------------

%package -n %{develname}
Summary:        Programming library for writing an XML-RPC server or client in C or C++
Group:          System/Libraries
Requires:       %{libname} = %version-%release
Requires:       %{name} >= %version
Requires:       libxml2-devel
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
XML-RPC is a quick-and-easy way to make procedure calls over the Internet.
It converts the procedure call into XML document, sends it to a remote
server using HTTP, and gets back the response as XML.

This library provides a modular implementation of XML-RPC for C and C++.

This package contains the developement files.

%files -n %{develname}
%{_bindir}/xmlrpc-c-config
%{_includedir}/*.h
%{_includedir}/%name/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

#--------------------------------------------------------------------

%prep
%autosetup -Sgit

%build
%meson %{?with_libxml2:-Dlibxml2-backend=true}
%meson_build

%install
%meson_install

%check
unset PKG_CONFIG_PATH
export PKG_CONFIG_LIBDIR=%buildroot%_libdir/pkgconfig:%_libdir/pkgconfig:%_datadir/pkgconfig
PATH=%buildroot%_bindir:$PATH

_e() {
     echo "\$ $@"
     "$@"
}

set +x
_e xmlrpc-c-config --help
for comp in cgi-server server-util abyss-server client libwww-client; do
	for opt in '--version' '--libs'; do
		_e xmlrpc-c-config "$comp" $opt
	done
done
set -x


%changelog
* Fri Apr 29 2022 ns80 <ns80> 1.51.06-1.1.mga8
+ Revision: 1855157
- add patch from centos for CVE-2022-25235 (mga#30351)

* Thu Apr 23 2020 daviddavid <daviddavid> 1.51.06-1.mga8
+ Revision: 1571175
- new version: 1.51.06

* Thu Feb 20 2020 umeabot <umeabot> 1.51.05-2.mga8
+ Revision: 1547359
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 1.51.05-1.mga8
+ Revision: 1487995
- new version: 1.51.05

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.51.03-2.mga8
+ Revision: 1476028
- rebuild for readline

* Sun Apr 21 2019 daviddavid <daviddavid> 1.51.03-1.mga7
+ Revision: 1394284
- new version: 1.51.03

* Thu Apr 18 2019 umeabot <umeabot> 1.51.0-3.mga7
+ Revision: 1392982
- Rebuild with meson 0.50.1

* Sun Sep 23 2018 umeabot <umeabot> 1.51.0-2.mga7
+ Revision: 1301936
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 pterjan <pterjan> 1.51.0-1.mga7
+ Revision: 1214828
- Update to 1.51.0 and partially sync with fedora

* Tue Jan 02 2018 wally <wally> 1.29.0-8.mga7
+ Revision: 1189483
- rebuild for new readline

* Tue Mar 01 2016 pterjan <pterjan> 1.29.0-7.mga6
+ Revision: 981500
- add missing dependency from -devel to the binaries

* Mon Feb 08 2016 umeabot <umeabot> 1.29.0-6.mga6
+ Revision: 943539
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.29.0-5.mga5
+ Revision: 743611
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.29.0-4.mga5
+ Revision: 690704
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.29.0-3.mga4
+ Revision: 520725
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.29.0-2.mga3
+ Revision: 387189
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 16 2012 dmorgan <dmorgan> 1.29.0-1.mga2
+ Revision: 196758
- New version 1.29.0
  Sync patches with fedora

* Sun May 15 2011 pterjan <pterjan> 1.20.3-5.mga1
+ Revision: 99045
- Rebuild for fixed find-requires

* Wed Apr 27 2011 dmorgan <dmorgan> 1.20.3-4.mga1
+ Revision: 92205
- Rebuild because of missing package in i586
+ pterjan <pterjan>
- Drop old conflicts/obsoletes
- imported package xmlrpc-c


* Sat Dec 04 2010 Oden Eriksson <oeriksson@mandriva.com> 1.20.3-3mdv2011.0
+ Revision: 608224
- rebuild

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - rebuild for ncurse support

* Sun Nov 29 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.20.3-1mdv2010.1
+ Revision: 471450
- fix lib64 build
- take upstream version from subversion, as there is no tarball release
  available
- sync with fedora package

* Thu Jan 22 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.06.27-5mdv2009.1
+ Revision: 332399
- don't modify Makefile.common for setting %%{optflags}, override the variables by
  passing them to 'make', also compile with -O3 which is suggsted by the default
  compile flags
- ensure that libtool and friends gets updated, otherwise ancient libtool will
  be used, resulting in inability to link against correct libraries, thus leaving
  the build completely broken

* Wed Jan 21 2009 Helio Chissini de Castro <helio@mandriva.com> 1.06.27-4mdv2009.1
+ Revision: 332216
- Rraise release to recompile and solve xml2 linking issues in the library

* Sun Sep 07 2008 Gaëtan Lehmann <glehmann@mandriva.org> 1.06.27-3mdv2009.0
+ Revision: 282075
- * rebuild for new libxml2
  * devel package requires libxml2-devel

* Sun Jul 13 2008 Funda Wang <fwang@mandriva.org> 1.06.27-2mdv2009.0
+ Revision: 234252
- move xmlrpc-c-config into devel package

* Sun Jul 13 2008 Funda Wang <fwang@mandriva.org> 1.06.27-1mdv2009.0
+ Revision: 234251
- BR xml2
- fix typo of develname
- use own optflags
- New version 1.06.27
- merge gentoo patches

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Nicolas Vigier <nvigier@mandriva.com>
    - add Provides on libxmlrpc-c-devel

* Wed May 23 2007 Nicolas Vigier <nvigier@mandriva.com> 1.06.14-1mdv2008.0
+ Revision: 30032
- Update to version 1.06.14

* Wed May 09 2007 Nicolas Vigier <nvigier@mandriva.com> 1.06.13-1mdv2008.0
+ Revision: 25644
- Import xmlrpc-c

